@@ -3,9 +3,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 from datetime import date,datetime,timedelta
 
-file_confirmed = 'data/time_series_19-covid-Confirmed.csv'
-file_recovered = 'data/time_series_19-covid-Recovered.csv'
-file_deaths = 'data/time_series_19-covid-Deaths.csv'
+file_confirmed = 'https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_19-covid-Confirmed.csv'
 
 def get_confirmed_cases():
     return pd.read_csv(file_confirmed)
